@@ -8,7 +8,7 @@ See accompanying License file for license details
 
 =cut 
 
-use vars qw($VERSION); $VERSION = 'REL_4.15.1';
+use vars qw($VERSION); $VERSION = 'REL_4.10';
 
 use strict;
 use warnings;
@@ -16,10 +16,6 @@ use Fcntl qw(:flock :seek);
 use PGBuild::Options;
 use File::Basename;
 
-# older msys is ging to use a different perl to run LWP, so we can't absolutely
-# require this module there
-BEGIN { require LWP::Simple if $^O ne 'msys' || $^V ge v5.8.0; }
-
 my %branch_last;
 sub branch_last_sort;
 
@@ -59,8 +55,7 @@ unless (
         ref $PGBuild::conf{branches_to_build} eq 'ARRAY'
         &&@{$PGBuild::conf{branches_to_build}}
     )
-    ||$PGBuild::conf{branches_to_build} =~
-    /^(ALL|HEAD_PLUS_LATEST|HEAD_PLUS_LATEST\d)$/
+    ||$PGBuild::conf{branches_to_build} eq 'ALL'
   )
 {
     die "no branches_to_build specified in $buildconf";
@@ -71,12 +66,9 @@ if (ref $PGBuild::conf{branches_to_build})
 {
     @branches = @{$PGBuild::conf{branches_to_build}};
 }
-elsif ($PGBuild::conf{branches_to_build} =~
-    /^(ALL|HEAD_PLUS_LATEST|HEAD_PLUS_LATEST(\d))$/ )
+elsif ($PGBuild::conf{branches_to_build} eq 'ALL' )
 {
 
-    my $latest = $2;
-
     # Need to set the path here so we make sure we pick up the right perl.
     # It has to be the perl that the build script would choose
     # i.e. specially *not* the MinGW SDK perl that is invoked for the
@@ -86,22 +78,12 @@ elsif ($PGBuild::conf{branches_to_build} =~
     $ENV{PATH} = $PGBuild::conf{build_env}->{PATH}
       if ($PGBuild::conf{build_env}->{PATH});
     (my $url = $PGBuild::conf{target}) =~s/cgi-bin.*/branches_of_interest.txt/;
-    my $branches_of_interest =(
-        ($^O eq 'msys' && $^V lt v5.8.0)
-        ? # msys: use perl in PATH
-          `perl -MLWP::Simple -e "getprint(q{$url})"`
-        : # everyone else: use this perl
-          LWP::Simple::get($url)
-    );
+    my $branches_of_interest = `perl -MLWP::Simple -e "getprint(q{$url})"`;
     die "getting branches of interest" unless $branches_of_interest;
     $ENV{PATH} = $save_path;
     push(@branches,$_)foreach (split(/\s+/,$branches_of_interest));
     @branches = grep {$_ ne 'REL8_2_STABLE'} @branches
       if  $PGBuild::conf{using_msvc};
-    splice(@branches,0,-2)
-      if $PGBuild::conf{branches_to_build} eq 'HEAD_PLUS_LATEST';
-    splice(@branches,0,0 - ($latest + 1))
-      if $PGBuild::conf{branches_to_build} =~ /^HEAD_PLUS_LATEST\d$/;
 }
 
 @branches = apply_throttle(@branches);
@@ -153,10 +135,6 @@ elsif ($run_one)
     }
 }
 
-# clean up the lockfile when we're done.
-close $lockfile;
-unlink $lockfilename;
-
 exit 0;
 
 ##########################################################
