@@ -32,11 +32,10 @@ See accompanying License file for license details
 
 ###################################################
 
-use vars qw($VERSION); $VERSION = 'REL_4.15.1';
+use vars qw($VERSION); $VERSION = 'REL_4.10';
 
 use strict;
 use warnings;
-use Config;
 use Fcntl qw(:flock :seek);
 use File::Path;
 use File::Copy;
@@ -74,7 +73,6 @@ BEGIN
 
 use PGBuild::SCM;
 use PGBuild::Options;
-use PGBuild::WebTxn;
 
 my %module_hooks;
 my $orig_dir = getcwd();
@@ -142,26 +140,21 @@ require $buildconf;
 
 # get the config data into some local variables
 my (
-    $buildroot,$target,$animal,
-    $aux_path,$trigger_exclude,$trigger_include,
-    $secret,$keep_errs,$force_every,
-    $make, $optional_steps,$use_vpath,
-    $tar_log_cmd, $using_msvc, $extra_config,
-    $make_jobs,$core_file_glob, $ccache_failure_remove
+    $buildroot,$target,$animal, $print_success,
+    $aux_path,$trigger_exclude,$trigger_include,$secret,
+    $keep_errs,$force_every, $make, $optional_steps,
+    $use_vpath,$tar_log_cmd, $using_msvc, $extra_config,
+    $make_jobs
   )
   =@PGBuild::conf{
-    qw(build_root target animal aux_path trigger_exclude
+    qw(build_root target animal print_success aux_path trigger_exclude
       trigger_include secret keep_error_builds force_every make optional_steps
-      use_vpath tar_log_cmd using_msvc extra_config make_jobs core_file_glob
-      ccache_failure_remove)
+      use_vpath tar_log_cmd using_msvc extra_config make_jobs)
   };
 
 #default is no parallel build
 $make_jobs ||= 1;
 
-# default core file pattern is Linux, which used to be hardcoded
-$core_file_glob ||= 'core*';
-
 # legacy name
 if (defined($PGBuild::conf{trigger_filter}))
 {
@@ -185,7 +178,7 @@ if (ref($force_every) eq 'HASH')
 my $config_opts = $PGBuild::conf{config_opts};
 my $scm = new PGBuild::SCM \%PGBuild::conf;
 
-use vars qw($buildport);
+my $buildport;
 
 if (exists $PGBuild::conf{base_port})
 {
@@ -202,8 +195,6 @@ else
     $buildport = $PGBuild::conf{branch_ports}->{$branch} || 5999;
 }
 
-$ENV{EXTRA_REGRESS_OPTS} = "--port=$buildport";
-
 $tar_log_cmd ||= "tar -z -cf runlogs.tgz *.log";
 
 my $logdirname = "lastrun-logs";
@@ -242,13 +233,8 @@ if ( `uname -s 2>&1 ` =~ /CYGWIN/i )
     my @procs = `ps -ef`;
     die "cygserver not running" unless(grep {/cygserver/} @procs);
 }
-my $ccachedir = $PGBuild::conf{build_env}->{CCACHE_DIR};
-if (!$ccachedir && $PGBuild::conf{use_default_ccache_dir})
-{
-    $ccachedir = "$buildroot/ccache-$animal";
-    $ENV{CCACHE_DIR} = $ccachedir;
-}
-if ($ccachedir)
+my $ccachedir;
+if ( $ccachedir = $PGBuild::conf{build_env}->{CCACHE_DIR} )
 {
 
     # ccache is smart enough to create what you tell it is the cache dir, but
@@ -259,10 +245,7 @@ if ($ccachedir)
     $ccachedir = abs_path($ccachedir);
 }
 
-if ($^V lt v5.8.0)
-{
-    die "no aux_path in config file" unless $aux_path;
-}
+die "no aux_path in config file" unless $aux_path;
 
 die "cannot run as root/Administrator" unless ($using_msvc or $> > 0);
 
@@ -391,8 +374,7 @@ unless ($using_msvc)
 }
 
 # the time we take the snapshot
-use vars qw($now);
-$now=time;
+my $now=time;
 my $installdir = "$buildroot/$branch/inst";
 my $dbstarted;
 
@@ -444,11 +426,8 @@ END
             rmtree("$pgsql") unless ($from_source || $keepall);
         }
 
-        # only keep the cache in cases of success, if config flag is set
-        if ($ccache_failure_remove)
-        {
-            rmtree("$ccachedir") if $ccachedir;
-        }
+        # only keep the cache in cases of success
+        rmtree("$ccachedir") if $ccachedir;
     }
 
     # get the modules to clean up after themselves
@@ -475,7 +454,7 @@ END
 # is less efficient but it hardly matters here for this shallow
 # structure.
 
-eval Data::Dumper->Dump([$extra_config],['extra_config']);
+$extra_config = eval Dumper($extra_config);
 
 if ($extra_config &&  $extra_config->{DEFAULT})
 {
@@ -520,8 +499,6 @@ my $savescmlog = "";
 
 $ENV{PGUSER} = 'buildfarm';
 
-check_port_is_ok($buildport, 'Pre');
-
 if ($from_source_clean)
 {
     print time_str(),"cleaning source in $pgsql ...\n";
@@ -668,9 +645,6 @@ make_check();
 # contrib is builtunder standard build step for msvc
 make_contrib() unless ($using_msvc);
 
-make_testmodules()
-  if (!$using_msvc && ($branch eq 'HEAD' || $branch ge 'REL9_5'));
-
 make_doc() if (check_optional_step('build_docs'));
 
 make_install();
@@ -678,9 +652,6 @@ make_install();
 # contrib is installed under standard install for msvc
 make_contrib_install() unless ($using_msvc);
 
-make_testmodules_install()
-  if (!$using_msvc && ($branch eq 'HEAD' || $branch ge 'REL9_5'));
-
 process_module_hooks('configure');
 
 process_module_hooks('build');
@@ -689,8 +660,6 @@ process_module_hooks("check");
 
 process_module_hooks('install');
 
-make_bin_installcheck();
-
 foreach my $locale (@locales)
 {
     last unless step_wanted('install');
@@ -723,18 +692,11 @@ foreach my $locale (@locales)
         make_isolation_check($locale);
     }
 
-    if (
-        step_wanted('pl-install-check')
-        && (
-            (!$using_msvc && (grep {/--with-(perl|python|tcl)/ } @$config_opts))
-            || (
-                $using_msvc
-                && (   defined($config_opts->{perl})
-                    || defined($config_opts->{python})
-                    || defined($config_opts->{tcl}))
-            )
-        )
-      )
+    # releases 8.0 and earlier don't support the standard method for testing
+    # PLs so only check them for later versions
+
+    if (($branch eq 'HEAD' || $branch gt 'REL8_1')
+        && step_wanted('pl-install-check'))
     {
 
         # restart the db to clear the log file
@@ -764,20 +726,6 @@ foreach my $locale (@locales)
         make_contrib_install_check($locale);
     }
 
-    if (step_wanted('testmodules-install-check')
-        &&($branch eq 'HEAD' || $branch ge 'REL9_5'))
-    {
-        print time_str(),"restarting db ($locale)...\n" if $verbose;
-
-        stop_db($locale);
-        start_db($locale);
-
-        print time_str(),"running make test-modules installcheck ($locale)...\n"
-          if $verbose;
-
-        make_testmodules_install_check($locale);
-    }
-
     print time_str(),"stopping db ($locale)...\n" if $verbose;
 
     stop_db($locale);
@@ -803,8 +751,6 @@ if (check_optional_step('find_typedefs') || $find_typedefs)
     find_typedefs();
 }
 
-check_port_is_ok($buildport,'Post');
-
 # if we get here everything went fine ...
 
 my $saved_config = get_config_summary();
@@ -942,11 +888,10 @@ sub cleanlogs
 sub writelog
 {
     my $stage = shift;
-    my $fname = "$stage.log";
     my $loglines = shift;
     my $handle;
     my $lrname = $st_prefix . $logdirname;
-    open($handle,">$lrname/$fname") || die $!;
+    open($handle,">$lrname/$stage.log") || die $!;
     print $handle @$loglines;
     close($handle);
 }
@@ -1087,23 +1032,6 @@ sub make_contrib
     $steps_completed .= " Contrib";
 }
 
-sub make_testmodules
-{
-    return unless step_wanted('testmodules');
-    print time_str(),"running make testmodules ...\n" if $verbose;
-
-    my $make_cmd = $make;
-    $make_cmd = "$make -j $make_jobs"
-      if ($make_jobs > 1);
-    my @makeout = `cd $pgsql/src/test/modules && $make_cmd 2>&1`;
-    my $status = $? >> 8;
-    writelog('make-testmodules',\@makeout);
-    print "======== make testmodules log ===========\n",@makeout
-      if ($verbose > 1);
-    send_result('TestModules',$status,\@makeout) if $status;
-    $steps_completed .= " TestModules";
-}
-
 sub make_contrib_install
 {
     return
@@ -1123,23 +1051,6 @@ sub make_contrib_install
     $steps_completed .= " ContribInstall";
 }
 
-sub make_testmodules_install
-{
-    return
-      unless (step_wanted('testmodules')
-        and step_wanted('install'));
-    print time_str(),"running make testmodules install ...\n"
-      if $verbose;
-
-    my @makeout = `cd $pgsql/src/test/modules && $make install 2>&1`;
-    my $status = $? >>8;
-    writelog('install-testmodules',\@makeout);
-    print "======== make testmodules install log ===========\n",@makeout
-      if ($verbose > 1);
-    send_result('TestModulesInstall',$status,\@makeout) if $status;
-    $steps_completed .= " TestModulesInstall";
-}
-
 sub initdb
 {
     my $locale = shift;
@@ -1258,7 +1169,7 @@ sub get_stack_trace
     my $pgdata = shift;
 
     # no core = no result
-    my @cores = glob("$pgdata/$core_file_glob");
+    my @cores = glob("$pgdata/core*");
     return () unless @cores;
 
     # no gdb = no result
@@ -1266,24 +1177,16 @@ sub get_stack_trace
     my $status = $? >>8;
     return () if $status;
 
-    my $cmdfile = "./gdbcmd";
-    my $handle;
-    open($handle, ">$cmdfile");
-    print $handle "bt\n";
-    close($handle);
-
     my @trace;
 
     foreach my $core (@cores)
     {
-        my @onetrace = `gdb -x $cmdfile --batch $bindir/postgres $core 2>&1`;
+        my @onetrace = `gdb -ex bt --batch $bindir/postgres $core 2>&1`;
         push(@trace,
             "\n\n================== stack trace: $core ==================\n",
             @onetrace);
     }
 
-    unlink $cmdfile;
-
     return @trace;
 }
 
@@ -1376,49 +1279,6 @@ sub make_contrib_install_check
     $steps_completed .= " ContribCheck-$locale";
 }
 
-sub make_testmodules_install_check
-{
-    my $locale = shift;
-    return unless step_wanted('testmodules-install-check');
-    my @checklog;
-    unless ($using_msvc)
-    {
-        @checklog =
-`cd $pgsql/src/test/modules && $make USE_MODULE_DB=1 installcheck 2>&1`;
-    }
-    else
-    {
-        chdir "$pgsql/src/tools/msvc";
-        @checklog = `perl vcregress.pl modulescheck 2>&1`;
-        chdir $branch_root;
-    }
-    my $status = $? >>8;
-    my @logs = glob("$pgsql/src/test/modules/*/regression.diffs");
-    push(@logs,"$installdir/logfile");
-    foreach my $logfile (@logs)
-    {
-        next unless (-e $logfile);
-        push(@checklog,"\n\n================= $logfile ===================\n");
-        my $handle;
-        open($handle,$logfile);
-        while(<$handle>)
-        {
-            push(@checklog,$_);
-        }
-        close($handle);
-    }
-    if ($status)
-    {
-        my @trace =get_stack_trace("$installdir/bin","$installdir/data");
-        push(@checklog,@trace);
-    }
-    writelog("testmodules-install-check-$locale",\@checklog);
-    print "======== make testmodules installcheck log ===========\n",@checklog
-      if ($verbose > 1);
-    send_result("TestModulesCheck-$locale",$status,\@checklog) if $status;
-    $steps_completed .= " TestModulesCheck-$locale";
-}
-
 sub make_pl_install_check
 {
     my $locale = shift;
@@ -1435,10 +1295,7 @@ sub make_pl_install_check
         chdir($branch_root);
     }
     my $status = $? >>8;
-    my @logs = (
-        glob("$pgsql/src/pl/*/regression.diffs"),
-        glob("$pgsql/src/pl/*/*/regression.diffs")
-    );
+    my @logs = glob("$pgsql/src/pl/*/regression.diffs");
     push(@logs,"$installdir/logfile");
     foreach my $logfile (@logs)
     {
@@ -1518,37 +1375,6 @@ sub make_isolation_check
     $steps_completed .= " IsolationCheck";
 }
 
-sub make_bin_installcheck
-{
-    return unless step_wanted('bin-installcheck');
-
-    # tests only came in with 9.4
-    return unless ($branch eq 'HEAD' or $branch ge 'REL9_4');
-
-    # Windows perls (except Cygwin) don't have IPC::Run,
-    # so don't even think about running
-    return if ($using_msvc or $^O eq 'msys');
-
-    # don't run unless the tests have been enabled
-    return unless grep {$_ eq '--enable-tap-tests' } @$config_opts;
-
-    print time_str(),"running make bin installcheck ...\n" if $verbose;
-
-    my @makeout = `cd $pgsql/src/bin && make NO_LOCALE=1 installcheck 2>&1`;
-
-    my $status = $? >>8;
-
-    # my @bases = glob("$pgsql/src/bin/*/tmp_check");
-    # XXX clean these up
-
-    writelog('bin-check',\@makeout);
-    print "======== make bin-install-check log ===========\n",@makeout
-      if ($verbose > 1);
-
-    send_result('BinInstallCheck',$status,\@makeout) if $status;
-    $steps_completed .= " BinInstallCheck";
-}
-
 sub make_check
 {
     return unless step_wanted('check');
@@ -1652,59 +1478,25 @@ sub make_ecpg_check
 
 sub find_typedefs
 {
-    my ($hostobjdump) = grep {/--host=/} @$config_opts;
-    $hostobjdump ||= "";
-    $hostobjdump =~ s/--host=(.*)/$1-objdump/;
-    my $objdump = 'objdump';
-    my $sep = $using_msvc ? ';' : ':';
-
-    # if we have a hostobjdump, find out which of it and objdump is in the path
-    foreach my $p (split(/$sep/,$ENV{PATH}))
-    {
-        last unless $hostobjdump;
-        last if (-e "$p/objdump" || -e "$p/objdump.exe");
-        if (-e "$p/$hostobjdump" || -e "$p/$hostobjdump.exe")
-        {
-            $objdump = $hostobjdump;
-            last;
-        }
-    }
+    my ($host) = grep {/--host=/} @$config_opts;
+    $host ||= "";
+    $host =~ s/--host=(.)/$1-objdump/;
+    my $objdump = $host || 'objdump';
     my @err = `$objdump -W 2>&1`;
     my @readelferr = `readelf -w 2>&1`;
-    my $using_osx = (`uname` eq "Darwin\n");
-    my @testfiles;
     my %syms;
     my @dumpout;
     my @flds;
 
-    if ($using_osx)
-    {
-
-        # On OS X, we need to examine the .o files
-        # exclude ecpg/test, which pgindent does too
-        my $obj_wanted = sub {
-            /^.*\.o\z/s
-              && !($File::Find::name =~ m!/ecpg/test/!s)
-              &&push(@testfiles, $File::Find::name);
-        };
-
-        File::Find::find($obj_wanted,$pgsql);
-    }
-    else
-    {
-
-        # Elsewhere, look at the installed executables and shared libraries
-        @testfiles = (
-            glob("$installdir/bin/*"),
-            glob("$installdir/lib/*"),
-            glob("$installdir/lib/postgresql/*")
-        );
-    }
-    foreach my $bin (@testfiles)
+    foreach my $bin (
+        glob("$installdir/bin/*"),
+        glob("$installdir/lib/*"),
+        glob("$installdir/lib/postgresql/*")
+      )
     {
         next if $bin =~ m!bin/(ipcclean|pltcl_)!;
         next unless -f $bin;
-        if (@err == 1) # Linux and sometimes windows
+        if (@err == 1) # Linux
         {
             @dumpout =
 `$objdump -W $bin 2>/dev/null | egrep -A3 DW_TAG_typedef 2>/dev/null`;
@@ -1732,19 +1524,6 @@ sub find_typedefs
                 $syms{$flds[-1]} =1;
             }
         }
-        elsif ($using_osx)
-        {
-            @dumpout =
-              `dwarfdump $bin 2>/dev/null | egrep -A2 TAG_typedef 2>/dev/null`;
-            foreach (@dumpout)
-            {
-                @flds = split;
-                next unless (@flds == 3);
-                next unless ($flds[0] eq "AT_name(");
-                next unless ($flds[1] =~ m/^"(.*)"$/);
-                $syms{$1} =1;
-            }
-        }
         else
         {
             @dumpout = `$objdump --stabs $bin 2>/dev/null`;
@@ -1775,20 +1554,9 @@ sub find_typedefs
         my $src = <$handle>;
         close($handle);
 
-        # strip C comments - see perlfaq6 for an explanation
-        # of the complex regex.
-        # On some platforms psqlscan.l  causes perl to barf and crash
-        # on the more complicated regexp, so fall back to the simple one.
-        # The results are most likely to be the same anyway.
-        if ($_ eq 'psqlscan.l')
-        {
-            $src =~ s{/\*.*?\*/}{}gs;
-        }
-        else
-        {
-            $src =~
+        # strip C comments - see perlfaq6
+        $src =~
 s#/\*[^*]*\*+([^/*][^*]*\*+)*/|("(\\.|[^"\\])*"|'(\\.|[^'\\])*'|.[^/"'\\]*)#defined $2 ? $2 : ""#gse;
-        }
         foreach my $word (split(/\W+/,$src))
         {
             $foundwords{$word} = 1;
@@ -1951,7 +1719,7 @@ sub send_result
     {
         $confsum= $saved_config;
     }
-    elsif ($stage !~ /CVS|Git|SCM|Pre-run-port-check/ )
+    elsif ($stage !~ /CVS|Git|SCM/ )
     {
         $confsum = get_config_summary();
     }
@@ -1998,7 +1766,7 @@ sub send_result
         }
     }
 
-    if ($stage !~ /CVS|Git|SCM|Pre-run-port-check/ )
+    if ($stage !~ /CVS|Git|SCM/ )
     {
 
         my @logfiles = glob("$lrname/*.log");
@@ -2021,30 +1789,28 @@ sub send_result
         unlink "$lrname/runlogs.tgz";
     }
 
-    my $txstatus;
+    unless (
+        -x "$aux_path/run_web_txn.pl"
+        ||($using_msvc && -f "$aux_path/run_web_txn.pl")
+      )
+    {
+        print "Could not locate $aux_path/run_web_txn.pl\n";
+        exit(1);
+    }
 
-    # this should now only apply to older Msys installs. All others should
-    # be running with perl >= 5.8 since that's required to build postgres
-    # anyway
-    if (!$^V or $^V lt v5.8.0)
+    if ($using_msvc)
     {
 
-        unless (-x "$aux_path/run_web_txn.pl")
-        {
-            print "Could not locate $aux_path/run_web_txn.pl\n";
-            exit(1);
-        }
-
-        $ENV{PERL5LIB} = $aux_path;
-        system("$aux_path/run_web_txn.pl $lrname");
-        $txstatus = $? >> 8;
+        # no shebang line for windows, but perl is in the path
+        system("perl \"$aux_path/run_web_txn.pl\" $lrname");
     }
     else
     {
-        $txstatus = PGBuild::WebTxn::run_web_txn($lrname) ? 0 : 1;
-
+        system("$aux_path/run_web_txn.pl $lrname");
     }
 
+    my $txstatus = $? >> 8;
+
     if ($txstatus)
     {
         print "Web txn failed with status: $txstatus\n";
@@ -2061,6 +1827,9 @@ sub send_result
         print "Buildfarm member $animal failed on $branch stage $stage\n";
     }
 
+    #	print "Success!\n",$response->content
+    #		if $print_success;
+
     set_last('success.snap',$current_snap) if ($stage eq 'OK' && !$nostatus);
 
     exit 0;
@@ -2106,38 +1875,6 @@ sub get_config_summary
     return $config;
 }
 
-sub check_port_is_ok
-{
-    my $port = shift;
-    my $report = shift; # Pre or Post
-    my $stage = "${report}-run-port-check";
-    my @log;
-    my $found = undef;
-
-    if ($Config{osname} !~ /msys|MSWin/)
-    {
-
-        # look for a unix socket except on Windows -
-        # cygwin does have them, though
-        # could connect, but just finding the socket file should do,
-        # since its existence will cause us grief.
-        $found = -S "/tmp/.s.PGSQL.$port";
-    }
-    if ($found)
-    {
-
-        # If we want to kill the process, do something likethis,
-        # but only in a Post checvk - don't kill any pre-existing
-        # process on the port:
-        # system("fuser -k /tmp/.s.PGSQL.$port") if $report eq 'Post';
-
-        # In either case finding this process is an error, so call
-        # send_result.
-        push(@log,"socket found listening to port $port");
-        send_result($stage,99,\@log);
-    }
-}
-
 sub get_script_config_dump
 {
     my $conf = {
